DKSGeneScores:
Class to contain dual Kolmogorov Smirnov rank sum discriminant
analysis results for gene expression data.
Description
The function dksTrain returns on object of class DKSGeneScore
to hold the analysis results for subsequent classifier extraction
and classification. This way, the gene scoring does not need to
be repeated for classifiers based on different numbers of genes.
Creating Objects
new("DKSGeneScore",
gscores.up=new("matrix"),
gscores.down=new("matrix"))Slots
gscores.up:- A matrix of gene scores, one column per
class
gscores.down:- A matrix of gene scores, one column per
class