DKSPredicted:
Class to contain classification results from dksClassify
Description
The function dksClassify calculates a score for each possible
class (as determined by the DKSGeneSet passed to it) for each
sample in the test set passed to the function. It then determines which
class each sample most likely belongs to based on which of those scores is
the largest. All this information is useful after the analysis, and so it is
retained in the return object of class DKSPredicted.
Creating Objects
new("DKSPredicted",
samples=new("vector"),
predictedClass=new("factor"),
predictedScore=new("vector"),
scoreMatrix=new("matrix")) Slots
samples:- A vector of sample names
predictedClass:- A factor specifying which class each sample
belongs to based on the classification.
predictedScore:- A vector giving the score corresponding to
the assigned class for each sample.
scoreMatrix:- The complete score matrix for future reference.
Methods
Standard generic methods:
plot(DKSPredicted):- Plot scores for each sample and class sorted,
in turn, by each class.
plot(DKSPredicted,missing):- Plot scores for each sample and class sorted,
in turn, by each class.
summary(DKSPredicted):- Display summary information for the classification.
summary(DKSPredicted, factor):- Display summary information for the
classification including the percent correctly classified (as specified by the factor).
show(DKSPredicted):- Displays a table of scores and predicted classes for each
sample.