dksSelectGenes: Extract gene signatures from a DKSGeneScores object.
Description
The DKSGeneScores returned by dksTrain holds
the rank data for all the genes in the original ExpressioSet.
However, generally only the top n genes for each class are desired
for classification. Rather than needing to re-run dksTrain
every time a signature of different size (n) is desired, you
simply extract that top n genes from this object using dksSelectGenes.
Usage
dksSelectGenes(data, n)
Arguments
data
An object of class DKSGeneScores, typically generated
by dksTrain
n
The number of genes, per class, to include in the classification
signature.