dksTrain(eset, class, type = "up", verbose=FALSE, weights=FALSE, logweights=TRUE, method='kort')ExpressionSet or matrixDKSGeneScores.
If weights=FALSE, signatures are defined based on the ranks of members of each class when sorted on each gene. Those genes for which a given class has the highest rank when sorting samples by those genes will be included in the classifier, with no regard to the absolute expression level of those genes. This is the classic KS statistic.
Very discriminant genes identified in this way may or may not be the
highest expressed genes. The result is that signatures identified
in this way have arbitrary "baseline" values. This may lead to
misclassification when comparing two signatures (using, for example,
dksClassify). Therefore, one may wish to weight genes
based on absolute expression level, or some other metric.
Setting weights = TRUE causes the genes to be weighted according
to the log (base 10) of the relative rank of the mean expression of
each gene in each class. Alternatively, you may provide your own weight
matrix as the argument to weights. This matrix must have one
column for each possible value of class, and one row for each
gene in eset. Note that for type='down' or the down
component of type='both', the weight matrix will be inverted
as 1-matrix, so the range of weights should be 0 - 1 for each
class. NAs are handled "gracefully" by discarding any
genes for which any column of the corresponding row of weights
is NA. Our experience has been that weights that are a linear function
of some feature of the gene expression (like mean) can be too subtle. The
effect of the weights can be increased by setting logweights=TRUE
(which is the default).
dksTrain, dksSelectGenes,
dksClassify, DKSGeneScores,
DKSPredicted,
DKSClassifier data("dks")
tr <- dksTrain(eset, 1, "up")
cl <- dksSelectGenes(tr, 100)
pr <- dksClassify(eset, cl)
summary(pr, pData(eset)[,1])
show(pr)
plot(pr, actual=pData(eset)[,1])
Run the code above in your browser using DataLab