| Package: |
| dualKS |
| Type: |
| Package |
| Version: |
| 1.0 |
| Date: |
| 2008-04-18 |
| License: |
| GPL-3 |
Use of this package requires an ExpressionSet, pre-processed
to your liking, containing gene expression data you wish to train on
to identify discriminant genes. Optionally, a second ExpressionSet
may be employed for subsequent testing or "diagnosis".
If the ExpressionSet does not contain the appropriate phenoData
specifying the classes for each sample, a factor containing this information
will also be required.
See the examples for further details.