dksWeights: Calculate gene weights based on average expression.
Description
Prior to selecting genes it may be desirable to calculate weights
for each genes so that some genes are more likely than others to be
included in the gene signature all other things being equal. This
function will calculate an N x M weight matrix for N genes in data
and M unique classes in class. The weights are based on
mean expression of each gene in each class such that genes that are
highly expressed on average in a given class will be weighted more
highly when scoring genes for that class.
The resulting weight matrix can be bassed to dksTrain as
the weights argument.
Usage
dksWeights(eset, class)
Arguments
eset
An ExpressionSet or matrix containing the gene
expression data to be used for bootstrapping.
class
A factor with two or more levels indicating which
class each sample in the expression set belongs OR
an integer indicating which column of pData(eset)
contains this information.
Value
An N x M matrix containing the weights for each gene and each class.